@@ -2,7 +2,7 @@ hist.metropolis <-
 function(x,density=TRUE,...)
 {
 	k <- x$input$k
-	layout(matrix(1:k,nc=k))
+	layout(matrix(1:k,ncol=k))
 	for(i in 1:k)
 	{
 		hist(x$sims[,i],main=colnames(x$sims)[i],freq=FALSE,xlab='',...)
